mysql.exceptions.server.M_Bigger_Than_D

Package mysql :: Package exceptions :: Module server :: Class M_Bigger_Than_D |
[hide private]
[frames] | no frames]

# Class M_Bigger_Than_D

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  M_Bigger_Than_D

For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column '%s').

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`